import os
import sys
from pathlib import Path
import bokeh
from notebook.nbextensions import install_nbextension

os.chdir(Path(__file__).parent)
alias = Path(install_nbextension('bokeh_resources')) / 'static'
target = Path(bokeh.__file__).parent / 'server' / 'static'
print(f'Creating symlink {alias}\n     pointing to {target}')
if alias.exists():
    if len(sys.argv) > 1 and sys.argv[1] in ('-f', '--force'):
        alias.unlink()
        print(f'Deleted symlink {alias}')
    else:
        print('Symlink already exists, exiting (use -f/--force to overwrite).')
        sys.exit(1)
if sys.platform == 'win32':
    os.system(f'mklink /j {alias} {target}')
else:
    alias.symlink_to(target)
print('Symlink created')



#!/usr/bin/env python

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="bokeh-resources",
    version="0.3",
    author='Lev Maximov',
    author_email='lev.maximov@gmail.com',
    url='https://github.com/axil/bokeh-resources',
    description="Jupyter extension to serve bokeh resources (js and css files).",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=['bokeh', 'notebook'],
    packages=['bokeh_resources', 'bokeh_resources.bokeh_resources'],
    package_data={'': ['*.js']},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    license="MIT License",
    zip_safe=False,
    keywords=['bokeh', 'jupyter', 'notebook'],
)
